@@ -80,7 +80,7 @@ struct _MetaWaylandCompositor
   struct wl_resource *xserver_resource;
 
   MetaLauncher *launcher;
-  int drm_fd;
+  gboolean native;
 
   MetaWaylandSeat *seat;
 };
@@ -99,7 +99,6 @@ void                    meta_wayland_compositor_set_input_focus (MetaWaylandComp
 gboolean                meta_wayland_compositor_handle_event    (MetaWaylandCompositor *compositor,
                                                                  const ClutterEvent    *event);
 
-MetaLauncher           *meta_wayland_compositor_get_launcher    (MetaWaylandCompositor *compositor);
 gboolean                meta_wayland_compositor_is_native       (MetaWaylandCompositor *compositor);
 
 MetaWaylandBuffer *     meta_wayland_buffer_from_resource       (struct wl_resource *resource);
